==> aime_0.59.orig.tar.gz: aime-0.59.orig/include/commands.h <==
#ifndef _COMMANDS_H
#define _COMMANDS_H

#include "config.h"

void shoutcom(Parse *the_parsed, MudObject *the_user);
void gocom(Parse *the_parsed, MudObject *the_user);
void lookcom(Parse *the_parsed, MudObject *the_user);
void exitscom(Parse *the_parsed, MudObject *the_user);
void saycom(Parse *the_parsed, MudObject *the_user);
void opencom(Parse *the_parsed, MudObject *the_user);
void closecom(Parse *the_parsed, MudObject *the_user);
void dropcom(Parse *the_parsed, MudObject *the_user);
void getcom(Parse *the_parsed, MudObject *the_user);
void inventorycom(Parse *the_parsed, MudObject *the_user);
void shutdowncom(Parse *the_parsed, MudObject *the_user);
void bhostscom(Parse *the_parsed, MudObject *the_user);
void banhostscom(Parse *the_parsed, MudObject *the_user);
void flagscom(Parse *the_parsed, MudObject *the_user);
void savecom(Parse *the_parsed, MudObject *the_user);
void reloadcom(Parse *the_parsed, MudObject *the_user);
void doorlockcom(Parse *the_parsed, MudObject *the_user);
void doorunlockcom(Parse *the_parsed, MudObject *the_user);
void readcom(Parse *the_parsed, MudObject *the_user);
void tellcom(Parse *the_parsed, MudObject *the_user);
void movecom(Parse *the_parsed, MudObject *the_user);
void gotocom(Parse *the_parsed, MudObject *the_user);
void givecom(Parse *the_parsed, MudObject *the_user);
void autoexitscom(Parse *the_parsed, MudObject *the_user);
void colorcom(Parse *the_parsed, MudObject *the_user);
void disconnectcom(Parse *the_parsed, MudObject *the_user);
void wieldcom(Parse *the_parsed, MudObject *the_user);
void unwieldcom(Parse *the_parsed, MudObject *the_user);
void putcom(Parse *the_parsed, MudObject *the_user);
void wearcom(Parse *the_parsed, MudObject *the_user);
void removecom(Parse *the_parsed, MudObject *the_user);
void statscom(Parse *the_parsed, MudObject *the_user);
void eatcom(Parse *the_parsed, MudObject *the_user);
void lightcom(Parse *the_parsed, MudObject *the_user);
void extinguishcom(Parse *the_parsed, MudObject *the_user);
void killcom(Parse *the_parsed, MudObject *the_user);
void summoncom(Parse *the_parsed, MudObject *the_user);
void conditioncom(Parse *the_parsed, MudObject *the_user);
void emotecom(Parse *the_parsed, MudObject *the_user);
void abilitiescom(Parse *the_parsed, MudObject *the_user);
void weaponscom(Parse *the_parsed, MudObject *the_user);
void castcom(Parse *the_parsed, MudObject *the_user);
void performcom(Parse *the_parsed, MudObject *the_user);
void setcom(Parse *the_parsed, MudObject *the_user);
void repeatcom(Parse *the_parsed, MudObject *the_user);
void briefcom(Parse *the_parsed, MudObject *the_user);
void autopaycom(Parse *the_parsed, MudObject *the_user);
void suggestcom(Parse *the_parsed, MudObject *the_user);
void bugcom(Parse *the_parsed, MudObject *the_user);
void timecom(Parse *the_parsed, MudObject *the_user);
void considercom(Parse *the_parsed, MudObject *the_user);
void diagnosecom(Parse *the_parsed, MudObject *the_user);
void sitcom(Parse *the_parsed, MudObject *the_user);
void standcom(Parse *the_parsed, MudObject *the_user);
void sleepcom(Parse *the_parsed, MudObject *the_user);
void tiecom(Parse *the_parsed, MudObject *the_user);
void untiecom(Parse *the_parsed, MudObject *the_user);
void logcom(Parse *the_parsed, MudObject *the_user);
void playcom(Parse *the_parsed, MudObject *the_user);
void noslaincom(Parse *the_parsed, MudObject *the_user);
void entercom(Parse *the_parsed, MudObject *the_user);
void leavecom(Parse *the_parsed, MudObject *the_user);
void fulleditcom(Parse *the_parsed, MudObject *the_user);
void mailcom(Parse *the_parsed, MudObject *the_user);
void typocom(Parse *the_parsed, MudObject *the_user);
void pronounscom(Parse *the_parsed, MudObject *the_user);
void pagercom(Parse *the_parsed, MudObject *the_user);
void digcom(Parse *the_parsed, MudObject *the_user);
void listencom(Parse *the_parsed, MudObject *the_user);
void smellcom(Parse *the_parsed, MudObject *the_user);
void fullexitscom(Parse *the_parsed, MudObject *the_user);
void attributescom(Parse *the_parsed, MudObject *the_user);
void bulletincom(Parse *the_parsed, MudObject *the_user);
void qinfocom(Parse *the_parsed, MudObject *the_user);
void questscom(Parse *the_parsed, MudObject *the_user);
void autodiagnosecom(Parse *the_parsed, MudObject *the_user);
void socketcom(Parse *the_parsed, MudObject *the_user);
void maskcom(Parse *the_parsed, MudObject *the_user);
void slaycom(Parse *the_parsed, MudObject *the_user);
void deleteuser(Parse *the_parsed, MudObject *the_user);
void clonecom(Parse *the_parsed, MudObject *the_user);
void forcecom(Parse *the_parsed, MudObject *the_user);
void bootcom(Parse *the_parsed, MudObject *the_user);
void listcom(Parse *the_parsed, MudObject *the_user);
void classifycom(Parse *the_parsed, MudObject *the_user);

#endif

==> aime_0.60.3.orig.tar.gz: aime-0.60.3.orig/include/commands.h <==
#ifndef _COMMANDS_H
#define _COMMANDS_H

#include "config.h"

void shoutcom(Parse *the_parsed, MudObject *the_user);
void gocom(Parse *the_parsed, MudObject *the_user);
void incognitocom(Parse *the_parsed, MudObject *the_user);
void admininviscom(Parse *the_parsed, MudObject *the_user);
void visiblecom(Parse *the_parsed, MudObject *the_user);
void lookcom(Parse *the_parsed, MudObject *the_user);
void exitscom(Parse *the_parsed, MudObject *the_user);
void saycom(Parse *the_parsed, MudObject *the_user);
void opencom(Parse *the_parsed, MudObject *the_user);
void closecom(Parse *the_parsed, MudObject *the_user);
void dropcom(Parse *the_parsed, MudObject *the_user);
void getcom(Parse *the_parsed, MudObject *the_user);
void inventorycom(Parse *the_parsed, MudObject *the_user);
void shutdowncom(Parse *the_parsed, MudObject *the_user);
void bhostscom(Parse *the_parsed, MudObject *the_user);
void banhostscom(Parse *the_parsed, MudObject *the_user);
void flagscom(Parse *the_parsed, MudObject *the_user);
void savecom(Parse *the_parsed, MudObject *the_user);
void reloadcom(Parse *the_parsed, MudObject *the_user);
void doorlockcom(Parse *the_parsed, MudObject *the_user);
void doorunlockcom(Parse *the_parsed, MudObject *the_user);
void readcom(Parse *the_parsed, MudObject *the_user);
void tellcom(Parse *the_parsed, MudObject *the_user);
void movecom(Parse *the_parsed, MudObject *the_user);
void gotocom(Parse *the_parsed, MudObject *the_user);
void givecom(Parse *the_parsed, MudObject *the_user);
void autoexitscom(Parse *the_parsed, MudObject *the_user);
void colorcom(Parse *the_parsed, MudObject *the_user);
void disconnectcom(Parse *the_parsed, MudObject *the_user);
void wieldcom(Parse *the_parsed, MudObject *the_user);
void unwieldcom(Parse *the_parsed, MudObject *the_user);
void putcom(Parse *the_parsed, MudObject *the_user);
void wearcom(Parse *the_parsed, MudObject *the_user);
void removecom(Parse *the_parsed, MudObject *the_user);
void statscom(Parse *the_parsed, MudObject *the_user);
void eatcom(Parse *the_parsed, MudObject *the_user);
void lightcom(Parse *the_parsed, MudObject *the_user);
void extinguishcom(Parse *the_parsed, MudObject *the_user);
void killcom(Parse *the_parsed, MudObject *the_user);
void summoncom(Parse *the_parsed, MudObject *the_user);
void conditioncom(Parse *the_parsed, MudObject *the_user);
void emotecom(Parse *the_parsed, MudObject *the_user);
void abilitiescom(Parse *the_parsed, MudObject *the_user);
void weaponscom(Parse *the_parsed, MudObject *the_user);
void castcom(Parse *the_parsed, MudObject *the_user);
void performcom(Parse *the_parsed, MudObject *the_user);
void setcom(Parse *the_parsed, MudObject *the_user);
void repeatcom(Parse *the_parsed, MudObject *the_user);
void briefcom(Parse *the_parsed, MudObject *the_user);
void autopaycom(Parse *the_parsed, MudObject *the_user);
void suggestcom(Parse *the_parsed, MudObject *the_user);
void bugcom(Parse *the_parsed, MudObject *the_user);
void timecom(Parse *the_parsed, MudObject *the_user);
void considercom(Parse *the_parsed, MudObject *the_user);
void diagnosecom(Parse *the_parsed, MudObject *the_user);
void sitcom(Parse *the_parsed, MudObject *the_user);
void standcom(Parse *the_parsed, MudObject *the_user);
void sleepcom(Parse *the_parsed, MudObject *the_user);
void tiecom(Parse *the_parsed, MudObject *the_user);
void untiecom(Parse *the_parsed, MudObject *the_user);
void logcom(Parse *the_parsed, MudObject *the_user);
void playcom(Parse *the_parsed, MudObject *the_user);
void noslaincom(Parse *the_parsed, MudObject *the_user);
void entercom(Parse *the_parsed, MudObject *the_user);
void leavecom(Parse *the_parsed, MudObject *the_user);
void fulleditcom(Parse *the_parsed, MudObject *the_user);
void mailcom(Parse *the_parsed, MudObject *the_user);
void typocom(Parse *the_parsed, MudObject *the_user);
void pronounscom(Parse *the_parsed, MudObject *the_user);
void pagercom(Parse *the_parsed, MudObject *the_user);
void digcom(Parse *the_parsed, MudObject *the_user);
void listencom(Parse *the_parsed, MudObject *the_user);
void smellcom(Parse *the_parsed, MudObject *the_user);
void fullexitscom(Parse *the_parsed, MudObject *the_user);
void attributescom(Parse *the_parsed, MudObject *the_user);
void bulletincom(Parse *the_parsed, MudObject *the_user);
void qinfocom(Parse *the_parsed, MudObject *the_user);
void questscom(Parse *the_parsed, MudObject *the_user);
void autodiagnosecom(Parse *the_parsed, MudObject *the_user);
void socketcom(Parse *the_parsed, MudObject *the_user);
void maskcom(Parse *the_parsed, MudObject *the_user);
void slaycom(Parse *the_parsed, MudObject *the_user);
void deleteuser(Parse *the_parsed, MudObject *the_user);
void clonecom(Parse *the_parsed, MudObject *the_user);
void forcecom(Parse *the_parsed, MudObject *the_user);
void bootcom(Parse *the_parsed, MudObject *the_user);
void listcom(Parse *the_parsed, MudObject *the_user);
void classifycom(Parse *the_parsed, MudObject *the_user);

#endif
